@@ -21,13 +21,13 @@
 #define KORGANIZERPLUGININTERFACE_H
 
 #include <QObject>
-#include <pimcommon/plugininterface.h>
+#include <PimCommonAkonadi/PluginInterface>
 class KActionCollection;
 class KOrganizerPluginInterface : public PimCommon::PluginInterface
 {
     Q_OBJECT
 public:
-    explicit KOrganizerPluginInterface(QObject *parent = Q_NULLPTR);
+    explicit KOrganizerPluginInterface(QObject *parent = nullptr);
     ~KOrganizerPluginInterface();
     static KOrganizerPluginInterface *self();
 };
