@@ -22,8 +22,8 @@
 
 #include "controller.h"
 
-#include <Libkdepim/CollectionSearchJob>
-#include <Libkdepim/PersonSearchJob>
+#include <LibkdepimAkonadi/CollectionSearchJob>
+#include <LibkdepimAkonadi/PersonSearchJob>
 #include "korganizer_debug.h"
 
 #include <AkonadiCore/EntityTreeModel>
@@ -154,7 +154,7 @@ QVariant PersonNode::data(int role) const
     case Qt::DisplayRole: {
         QString name = mPerson.name;
         if (!mPerson.ou.isEmpty()) {
-            name += QStringLiteral(" (") + mPerson.ou + QStringLiteral(")");
+            name += QStringLiteral(" (") + mPerson.ou + QLatin1Char(')');
         }
         return name;
     }
@@ -338,7 +338,7 @@ void Controller::onCollectionsFound(KJob *job)
 
 void Controller::onPersonsFound(const QVector<KPIM::Person> &persons)
 {
-    Q_FOREACH (const KPIM::Person &p, persons) {
+    for (const KPIM::Person &p : persons) {
         PersonNode *personNode = new PersonNode(*mSearchModel, p);
         personNode->isSearchNode = true;
         //toggled by the checkbox, results in person getting added to main model
